@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -158,7 +158,7 @@ pref("gfx.downloadable_fonts.enabled", true);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 163 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 163 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -171,7 +171,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 179 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 179 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -517,6 +517,12 @@ pref("dom.disable_open_click_delay", 1000);
 pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
+// Parsing perf prefs. For now just mimic what the old code did.
+pref("content.sink.event_probe_rate", 3);
+//@line 527 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+pref("content.sink.pending_event_mode", 0);
+//@line 529 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+
 // Disable popups from plugins by default
 //   0 = openAllowed
 //   1 = openControlled
@@ -560,7 +566,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 570 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 576 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -793,7 +799,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 808 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 814 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -812,9 +818,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 828 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 834 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 835 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 841 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -832,7 +838,6 @@ pref("network.proxy.no_proxies_on",         "localhost, 127.0.0.1");
 pref("network.proxy.failover_timeout",      1800); // 30 minutes
 pref("network.online",                      true); //online/offline
 pref("network.cookie.cookieBehavior",       0); // 0-Accept, 1-dontAcceptForeign, 2-dontUse
-pref("network.cookie.disableCookieForMailNews", true); // disable all cookies for mail
 pref("network.cookie.lifetimePolicy",       0); // accept normally, 1-askBeforeAccepting, 2-acceptForSession,3-acceptForNDays
 pref("network.cookie.alwaysAcceptSessionCookies", false);
 pref("network.cookie.prefsMigrated",        false);
@@ -1177,15 +1182,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1576 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1581 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1993 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1998 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2194 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2199 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2288 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2293 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2291 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2296 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1453,15 +1458,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2561 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2566 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2629 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2634 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2655 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2660 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2675 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2680 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2683 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2688 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1485,7 +1490,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2712 "/builds/moz2_slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2717 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
